==> haskell-data-dword-0.3.2-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-dword
version:              0.3.2
visibility:           public
id:                   data-dword-0.3.2-5UPwUEMmbkUHYJ9xQHZvfI
key:                  data-dword-0.3.2-5UPwUEMmbkUHYJ9xQHZvfI
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  492b1f9c0e77688acf585584f8ed803f
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-8.10.2/site-local/data-dword-0.3.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/data-dword-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/data-dword-0.3.2
hs-libraries:         HSdata-dword-0.3.2-5UPwUEMmbkUHYJ9xQHZvfI
depends:
    base-4.14.1.0 data-bword-0.1.0.1-4wDu6Fank9iC93zANkYZRE
    ghc-prim-0.6.1 hashable-1.3.0.0-1lZSCDGnvrhIxi1kvployh
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.2-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-dword
version:              0.3.2
visibility:           public
id:                   data-dword-0.3.2-GnUrUwC420AEbwvjLmYi9v
key:                  data-dword-0.3.2-GnUrUwC420AEbwvjLmYi9v
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  ebc9d15e33410b6320c4276a3357e449
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-8.10.2/site-local/data-dword-0.3.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/data-dword-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/data-dword-0.3.2
hs-libraries:         HSdata-dword-0.3.2-GnUrUwC420AEbwvjLmYi9v
depends:
    base-4.14.1.0 data-bword-0.1.0.1-4wDu6Fank9iC93zANkYZRE
    ghc-prim-0.6.1 hashable-1.3.0.0-B8ECnPmIwukCF0VUFUS7Nf
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
